@@ -96,11 +96,9 @@ exp_generic(A) = exponential!(copy(A), ExpMethodGeneric())
     end
 end
 
-if VERSION >= v"1.9"
-    @testset "exponential! sparse" begin
-        A = sparse([1, 2, 1], [2, 1, 1], [1.0, 2.0, 3.0])
-        @test_throws ErrorException exponential!(A)
-    end
+@testset "exponential! sparse" begin
+    A = sparse([1, 2, 1], [2, 1, 1], [1.0, 2.0, 3.0])
+    @test_throws ErrorException exponential!(A)
 end
 
 @testset "Issue 41" begin
@@ -116,23 +114,19 @@ end
 @testset "Issue 143" begin
     ts = collect(0:0.1:1)
 
-    if VERSION >= v"1.7"
-        out = Pipe()
-        res = redirect_stdout(out) do
-            expv_timestep(ts, reshape([1], (1, 1)), [1.0]; verbose = true)
-        end
-        close(Base.pipe_writer(out))
-
-        @test occursin("Completed after 1 time step(s)", read(out, String))
-    else
-        res = expv_timestep(ts, reshape([1], (1, 1)), [1.0]; verbose = true)
+    out = Pipe()
+    res = redirect_stdout(out) do
+        expv_timestep(ts, reshape([1], (1, 1)), [1.0]; verbose = true)
     end
+    close(Base.pipe_writer(out))
+
+    @test occursin("Completed after 1 time step(s)", read(out, String))
 
     @test vec(res) ≈ exp.(ts)
 end
 
 @testset "naive_matmul" begin
-    A = Matrix(reshape((1.0:(23.0^2)) ./ 700, (23, 23)))
+    A = Matrix(reshape((1.0:(23.0 ^ 2)) ./ 700, (23, 23)))
     @test exp_generic(A) ≈ exp(A)
     # FiniteDiff.finite_difference_gradient(sum ∘ exp, A)
     @test ForwardDiff.gradient(sum ∘ exp_generic, A) ≈
@@ -221,10 +215,11 @@ end
 
 @testset "Static Arrays" begin
     Random.seed!(0)
-    for N in (3,4,6,8),t in (0.1,1.0,10.0)
-        A = I+randn(SMatrix{N,N,Float64})/3
-        b = randn(SVector{N,Float64})
-        @test expv(t,A,b) ≈ exp(t*A)*b
+    for N in (3, 4, 6, 8), t in (0.1, 1.0, 10.0)
+
+        A = I+randn(SMatrix{N, N, Float64})/3
+        b = randn(SVector{N, Float64})
+        @test expv(t, A, b) ≈ exp(t*A)*b
     end
 end
 
@@ -299,6 +294,7 @@ end
         rand(n, n)
     ]
         for b in [rand(ComplexF64, n), rand(n)], t in [1e-2, 1e-2im, 1e-2 + 1e-2im]
+
             @test exp(t * A) * b ≈ expv(t, A, b; m = m)
         end
     end
